==> create-fly-1.21.10-6.0.8-4-sources.jar: com/zurrtum/create/client/content/kinetics/mixer/MechanicalMixerRenderer.java <==
package com.zurrtum.create.client.content.kinetics.mixer;

import com.zurrtum.create.catnip.theme.Color;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.catnip.render.CachedBuffers;
import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import com.zurrtum.create.client.content.kinetics.base.KineticBlockEntityRenderer;
import com.zurrtum.create.client.flywheel.api.visualization.VisualizationManager;
import com.zurrtum.create.content.kinetics.base.IRotate;
import com.zurrtum.create.content.kinetics.mixer.MechanicalMixerBlockEntity;
import net.minecraft.class_11659;
import net.minecraft.class_11954;
import net.minecraft.class_12075;
import net.minecraft.class_1921;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5614;
import net.minecraft.class_827;
import org.jetbrains.annotations.Nullable;

public class MechanicalMixerRenderer implements class_827<MechanicalMixerBlockEntity, MechanicalMixerRenderer.MechanicalMixerRenderState> {
    public MechanicalMixerRenderer(class_5614.class_5615 context) {
    }

    @Override
    public boolean method_3563() {
        return true;
    }

    @Override
    public MechanicalMixerRenderState method_74335() {
        return new MechanicalMixerRenderState();
    }

    @Override
    public void updateRenderState(
        MechanicalMixerBlockEntity be,
        MechanicalMixerRenderState state,
        float tickProgress,
        class_243 cameraPos,
        class_11683.@Nullable class_11792 crumblingOverlay
    ) {
        class_1937 world = be.method_10997();
        if (VisualizationManager.supportsVisualization(world)) {
            return;
        }
        class_11954.method_74399(be, state, crumblingOverlay);
        state.layer = class_1921.method_23579();
        state.cogwheel = CachedBuffers.partial(AllPartialModels.SHAFTLESS_COGWHEEL, state.field_62674);
        class_2351 axis = ((IRotate) state.field_62674.method_26204()).getRotationAxis(state.field_62674);
        state.angle = KineticBlockEntityRenderer.getAngleForBe(be, state.field_62673, axis);
        state.direction = class_2350.method_10169(axis, class_2350.class_2352.field_11056);
        state.color = KineticBlockEntityRenderer.getColor(be);
        state.headOffset = -be.getRenderedHeadOffset(tickProgress);
        state.pole = CachedBuffers.partial(AllPartialModels.MECHANICAL_MIXER_POLE, state.field_62674);
        state.head = CachedBuffers.partial(AllPartialModels.MECHANICAL_MIXER_HEAD, state.field_62674);
        float speed = be.getRenderedHeadRotationSpeed(tickProgress);
        float time = AnimationTickHolder.getRenderTime(world);
        state.headAngle = ((time * speed * 6 / 10f) % 360) / 180 * (float) Math.PI;
    }

    @Override
    public void render(MechanicalMixerRenderState state, class_4587 matrices, class_11659 queue, class_12075 cameraState) {
        queue.method_73483(matrices, state.layer, state);
    }

    public static class MechanicalMixerRenderState extends class_11954 implements class_11659.class_11660 {
        public class_1921 layer;
        public float angle;
        public class_2350 direction;
        public Color color;
        public SuperByteBuffer cogwheel;
        public float headOffset;
        public SuperByteBuffer pole;
        public SuperByteBuffer head;
        public float headAngle;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            cogwheel.rotateCentered(angle, direction).color(color).light(field_62676).renderInto(matricesEntry, vertexConsumer);
            pole.translate(0, headOffset, 0).light(field_62676).renderInto(matricesEntry, vertexConsumer);
            head.rotateCentered(headAngle, class_2350.field_11036).translate(0, headOffset, 0).light(field_62676)
                .renderInto(matricesEntry, vertexConsumer);
        }
    }
}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/client/content/kinetics/mixer/MechanicalMixerRenderer.java <==
package com.zurrtum.create.client.content.kinetics.mixer;

import com.zurrtum.create.catnip.theme.Color;
import com.zurrtum.create.client.AllPartialModels;
import com.zurrtum.create.client.catnip.animation.AnimationTickHolder;
import com.zurrtum.create.client.catnip.render.CachedBuffers;
import com.zurrtum.create.client.catnip.render.SuperByteBuffer;
import com.zurrtum.create.client.content.kinetics.base.KineticBlockEntityRenderer;
import com.zurrtum.create.client.flywheel.api.visualization.VisualizationManager;
import com.zurrtum.create.content.kinetics.base.IRotate;
import com.zurrtum.create.content.kinetics.mixer.MechanicalMixerBlockEntity;
import net.minecraft.class_11659;
import net.minecraft.class_11683;
import net.minecraft.class_11954;
import net.minecraft.class_12075;
import net.minecraft.class_1921;
import net.minecraft.class_1937;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_243;
import net.minecraft.class_4587;
import net.minecraft.class_4588;
import net.minecraft.class_5614;
import net.minecraft.class_827;
import org.jetbrains.annotations.Nullable;

public class MechanicalMixerRenderer implements class_827<MechanicalMixerBlockEntity, MechanicalMixerRenderer.MechanicalMixerRenderState> {
    public MechanicalMixerRenderer(class_5614.class_5615 context) {
    }

    @Override
    public boolean method_3563() {
        return true;
    }

    @Override
    public MechanicalMixerRenderState method_74335() {
        return new MechanicalMixerRenderState();
    }

    @Override
    public void updateRenderState(
        MechanicalMixerBlockEntity be,
        MechanicalMixerRenderState state,
        float tickProgress,
        class_243 cameraPos,
        @Nullable class_11683.class_11792 crumblingOverlay
    ) {
        class_1937 world = be.method_10997();
        if (VisualizationManager.supportsVisualization(world)) {
            return;
        }
        class_11954.method_74399(be, state, crumblingOverlay);
        state.layer = class_1921.method_23579();
        state.cogwheel = CachedBuffers.partial(AllPartialModels.SHAFTLESS_COGWHEEL, state.field_62674);
        class_2351 axis = ((IRotate) state.field_62674.method_26204()).getRotationAxis(state.field_62674);
        state.angle = KineticBlockEntityRenderer.getAngleForBe(be, state.field_62673, axis);
        state.direction = class_2350.method_10169(axis, class_2350.class_2352.field_11056);
        state.color = KineticBlockEntityRenderer.getColor(be);
        state.headOffset = -be.getRenderedHeadOffset(tickProgress);
        state.pole = CachedBuffers.partial(AllPartialModels.MECHANICAL_MIXER_POLE, state.field_62674);
        state.head = CachedBuffers.partial(AllPartialModels.MECHANICAL_MIXER_HEAD, state.field_62674);
        float speed = be.getRenderedHeadRotationSpeed(tickProgress);
        float time = AnimationTickHolder.getRenderTime(world);
        state.headAngle = ((time * speed * 6 / 10f) % 360) / 180 * (float) Math.PI;
    }

    @Override
    public void render(MechanicalMixerRenderState state, class_4587 matrices, class_11659 queue, class_12075 cameraState) {
        queue.method_73483(matrices, state.layer, state);
    }

    public static class MechanicalMixerRenderState extends class_11954 implements class_11659.class_11660 {
        public class_1921 layer;
        public float angle;
        public class_2350 direction;
        public Color color;
        public SuperByteBuffer cogwheel;
        public float headOffset;
        public SuperByteBuffer pole;
        public SuperByteBuffer head;
        public float headAngle;

        @Override
        public void render(class_4587.class_4665 matricesEntry, class_4588 vertexConsumer) {
            cogwheel.rotateCentered(angle, direction).color(color).light(field_62676).renderInto(matricesEntry, vertexConsumer);
            pole.translate(0, headOffset, 0).light(field_62676).renderInto(matricesEntry, vertexConsumer);
            head.rotateCentered(headAngle, class_2350.field_11036).translate(0, headOffset, 0).light(field_62676)
                .renderInto(matricesEntry, vertexConsumer);
        }
    }
}
